==> jc-1.4.0.tar.gz: javax/naming/RefAddr.h <==
// public abstract class javax.naming.RefAddr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_RefAddr_H_
#define _JC_javax_naming_RefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_RefAddr$sub_refs	_jc_javax_naming_RefAddr$sub_refs;
typedef struct _jc_javax_naming_RefAddr$sub_nonrefs	_jc_javax_naming_RefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_RefAddr$refs	_jc_javax_naming_RefAddr$refs;
typedef struct _jc_javax_naming_RefAddr$nonrefs	_jc_javax_naming_RefAddr$nonrefs;
typedef struct _jc_javax_naming_RefAddr$object	_jc_javax_naming_RefAddr$object;

typedef const struct _jc_javax_naming_RefAddr$vmethods	_jc_javax_naming_RefAddr$vmethods;
typedef const struct _jc_javax_naming_RefAddr$vtable	_jc_javax_naming_RefAddr$vtable;
typedef const struct _jc_javax_naming_RefAddr$vtype	_jc_javax_naming_RefAddr$vtype;

// Constructors
extern void _jc_javax_naming_RefAddr$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_naming_RefAddr$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_RefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_RefAddr$method$getType$1756580bdd350fe6(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
extern jint _jc_javax_naming_RefAddr$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
extern struct _jc_java_lang_String$object *_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_RefAddr$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_RefAddr$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_naming_RefAddr$method_info$getContent$3271597a0076ff68;
extern _jc_method _jc_javax_naming_RefAddr$method_info$getType$1756580bdd350fe6;
extern _jc_method _jc_javax_naming_RefAddr$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_naming_RefAddr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_RefAddr$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
	struct _jc_java_lang_String$object	*(*getType$1756580bdd350fe6)(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_RefAddr$object *);
};

// Vtable
struct _jc_javax_naming_RefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
};

// Vtype
struct _jc_javax_naming_RefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_RefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_RefAddr$sub_refs {
	struct _jc_java_lang_String$object	*addrType;
};

// Reference instance fields (object)
struct _jc_javax_naming_RefAddr$refs {
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_RefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_RefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
};

// Object instance structure
struct _jc_javax_naming_RefAddr$object {
	_jc_javax_naming_RefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_RefAddr$vtype	*vtype;
	_jc_javax_naming_RefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_RefAddr$vtype _jc_javax_naming_RefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_RefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_RefAddr$class_object;

#endif	/* _JC_javax_naming_RefAddr_H_ */

==> jc-1.4.6.tar.gz: javax/naming/RefAddr.h <==
// public abstract class javax.naming.RefAddr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1aa52b9631354f18 javax_naming_RefAddr

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_naming_RefAddr_H_
#define _JC_javax_naming_RefAddr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_RefAddr$sub_refs	_jc_javax_naming_RefAddr$sub_refs;
typedef struct _jc_javax_naming_RefAddr$sub_nonrefs	_jc_javax_naming_RefAddr$sub_nonrefs;
typedef struct _jc_javax_naming_RefAddr$refs	_jc_javax_naming_RefAddr$refs;
typedef struct _jc_javax_naming_RefAddr$nonrefs	_jc_javax_naming_RefAddr$nonrefs;
typedef struct _jc_javax_naming_RefAddr$object	_jc_javax_naming_RefAddr$object;

typedef const struct _jc_javax_naming_RefAddr$vmethods	_jc_javax_naming_RefAddr$vmethods;
typedef const struct _jc_javax_naming_RefAddr$vtable	_jc_javax_naming_RefAddr$vtable;
typedef const struct _jc_javax_naming_RefAddr$vtype	_jc_javax_naming_RefAddr$vtype;

// Constructors
extern void _jc_javax_naming_RefAddr$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_naming_RefAddr$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_RefAddr$method$getContent$3271597a0076ff68(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_RefAddr$method$getType$1756580bdd350fe6(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_naming_RefAddr$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_naming_RefAddr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_RefAddr$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_naming_RefAddr$method_info$getContent$3271597a0076ff68;
extern _jc_method _jc_javax_naming_RefAddr$method_info$getType$1756580bdd350fe6;
extern _jc_method _jc_javax_naming_RefAddr$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_naming_RefAddr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_naming_RefAddr$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_naming_RefAddr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getContent$3271597a0076ff68)(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getType$1756580bdd350fe6)(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_naming_RefAddr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_RefAddr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_RefAddr$vmethods	javax_naming_RefAddr;
};

// Vtype
struct _jc_javax_naming_RefAddr$vtype {
	_jc_type			type;
	_jc_javax_naming_RefAddr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_RefAddr$sub_refs {
	struct _jc_java_lang_String$object	*addrType;
};

// Reference instance fields (object)
struct _jc_javax_naming_RefAddr$refs {
    _jc_javax_naming_RefAddr$sub_refs	javax_naming_RefAddr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_RefAddr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_RefAddr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_RefAddr$sub_nonrefs	javax_naming_RefAddr;
};

// Object instance structure
struct _jc_javax_naming_RefAddr$object {
	_jc_javax_naming_RefAddr$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_RefAddr$vtype	*vtype;
	_jc_javax_naming_RefAddr$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_RefAddr$vtype _jc_javax_naming_RefAddr$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_RefAddr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_RefAddr$class_object;

#endif	/* _JC_javax_naming_RefAddr_H_ */
